/*
 * glamour
 * Exported from glamour.gbt by GBA Tracker
 * Mon Nov 09 17:47:53 EST 2015
 */

// Defines for the interrupt handler
#define REG_IE        *(volatile unsigned short*) 0x4000200
#define REG_IF        *(volatile unsigned short*) 0x4000202
#define REG_IME       *(volatile unsigned short*) 0x4000208
#define IRQ_ENABLE    1
#define IRQ_VBLANK    (1 << 0)
#define IRQ_HBLANK    (1 << 1)
#define IRQ_VCOUNT    (1 << 2)
#define IRQ_TIMER(n)  (1 << (3 + (n)))
#define IRQ_COM       (1 << 7)
#define IRQ_DMA(n)    (1 << (8 + (n)))
#define IRQ_KEYPAD    (1 << 12)
#define IRQ_CARTRIDGE (1 << 13)
typedef void (*irqptr)(void);
#define REG_ISR_MAIN *(irqptr*) 0x3007FFC

// Defines for the timer
#define REG_TMD(n)   *(volatile unsigned short*) (0x4000100 + ((n) << 2))
#define REG_TMCNT(n) *(volatile unsigned short*) (0x4000102 + ((n) << 2))
#define TM_FREQ_1    0
#define TM_FREQ_64   1
#define TM_FREQ_256  2
#define TM_FREQ_1024 3
#define TM_CASCADE   (1 << 2)
#define TM_IRQ       (1 << 6)
#define TM_ENABLE    (1 << 7)

// Defines for sound control
#define REG_SND1SWP   *(volatile unsigned short*) 0x4000060 
#define REG_SND1ENV   *(volatile unsigned short*) 0x4000062
#define REG_SND1FRQ   *(volatile unsigned short*) 0x4000064
#define REG_SND2ENV   *(volatile unsigned short*) 0x4000068
#define REG_SND2FRQ   *(volatile unsigned short*) 0x400006C
#define REG_SND4ENV   *(volatile unsigned short*) 0x4000078
#define REG_SND4FRQ   *(volatile unsigned short*) 0x400007C
#define REG_SNDDMGCNT *(volatile unsigned short*) 0x4000080
#define REG_SNDSTAT   *(volatile unsigned short*) 0x4000084
#define MASTER_SND_EN (1 << 7)
#define MASTER_VOL25  0
#define MASTER_VOL50  1
#define MASTER_VOL100 2
#define LEFT_VOL(n)   (n)
#define RIGHT_VOL(n)  ((n) << 4)
#define CHAN_EN_L(n)  (1 << ((n) + 7))
#define CHAN_EN_R(n)  (1 << ((n) + 11))

#define BPM_QUAN_TRANSFORM -(0x14000/280)

// Defines and global variables used by the music handler
typedef struct {
	unsigned short CH1_SWP;
	unsigned short CH1_ENV;
	unsigned short CH1_FRQ;
	unsigned short CH2_ENV;
	unsigned short CH2_FRQ;
	unsigned short CH4_ENV;
	unsigned short CH4_FRQ;
	unsigned short LEN;
} note_t;

static void glamour_step();
static const note_t sound_data[642];
static int index, wait;

// Begin playing the music
void glamour_play() {

	REG_IME = 0;
	REG_ISR_MAIN = glamour_step;
	REG_IE = IRQ_TIMER(0);

	REG_TMD(0) = BPM_QUAN_TRANSFORM;
	REG_TMCNT(0) = TM_ENABLE | TM_IRQ | TM_FREQ_1024;

	REG_SNDSTAT = MASTER_SND_EN;
	REG_SNDDMGCNT = CHAN_EN_L(1) |
	                CHAN_EN_R(1) |
	                CHAN_EN_L(2) |
	                CHAN_EN_R(2) |
	                CHAN_EN_L(4) |
	                CHAN_EN_R(4) |
	                LEFT_VOL(7)  |
	                RIGHT_VOL(7);

	index = 0;
	wait = 1;
	
	REG_IME = IRQ_ENABLE;
}

// Stop playing the music
void glamour_stop() {
	REG_IME &= ~IRQ_ENABLE;
	REG_SNDSTAT &= ~MASTER_SND_EN;
}

// Play one 48th of a measure of music
static void glamour_step() {
	REG_IME = 0;
	int halt = 0;
	switch(REG_IF) {
	case IRQ_TIMER(0) :

		if(!--wait) {

			if(sound_data[index].CH1_FRQ) {
				REG_SND1SWP = sound_data[index].CH1_SWP;
				REG_SND1ENV = sound_data[index].CH1_ENV;
				REG_SND1FRQ = sound_data[index].CH1_FRQ;
			}
	
			if(sound_data[index].CH2_FRQ) {
				REG_SND2ENV = sound_data[index].CH2_ENV;
				REG_SND2FRQ = sound_data[index].CH2_FRQ;
			}
	
			if(sound_data[index].CH4_FRQ) {
				REG_SND4ENV = sound_data[index].CH4_ENV;
				REG_SND4FRQ = sound_data[index].CH4_FRQ;
			}
			
			wait = sound_data[index].LEN;
	
			if(++index == 642) {
				if(1) {
					index = 50;
				} else {
					halt = 1;
				}
			}
		}

		break;
	default:
		break;
	}

	REG_IF = REG_IF;
	if(!halt) {
		REG_IME = IRQ_ENABLE;
	}
}

// Note data
static const note_t sound_data[642] = {
	{0x0008,0xF280,0x81CA,0x0000,0x0000,0x0000,0x0000,0x0018},
	{0x0008,0xF280,0x82C8,0x0000,0x0000,0x0000,0x0000,0x0018},
	{0x0008,0xF280,0x8483,0x0000,0x0000,0x0000,0x0000,0x0012},
	{0x0008,0xF280,0x844F,0x0000,0x0000,0x0000,0x0000,0x0012},
	{0x0008,0xF280,0x81CA,0x0000,0x0000,0x0000,0x0000,0x0018},
	{0x0008,0xF280,0x81CA,0x0000,0x0000,0x0000,0x0000,0x000C},
	{0x0008,0xF280,0x82C8,0x0000,0x0000,0x0000,0x0000,0x0018},
	{0x0008,0xF280,0x8483,0x0000,0x0000,0x0000,0x0000,0x0012},
	{0x0008,0xF280,0x844F,0x0000,0x0000,0x0000,0x0000,0x001E},
	{0x0008,0xF280,0x81CA,0x0000,0x0000,0x0000,0x0000,0x0018},
	{0x0008,0xF280,0x82C8,0x0000,0x0000,0x0000,0x0000,0x0018},
	{0x0008,0xF280,0x8483,0x0000,0x0000,0x0000,0x0000,0x0012},
	{0x0008,0xF280,0x844F,0x0000,0x0000,0x0000,0x0000,0x0012},
	{0x0008,0xF280,0x81CA,0x0000,0x0000,0x0000,0x0000,0x0018},
	{0x0008,0xF280,0x81CA,0x0000,0x0000,0x0000,0x0000,0x000C},
	{0x0008,0xF280,0x82C8,0x0000,0x0000,0x0000,0x0000,0x0018},
	{0x0008,0xF280,0x8483,0x0000,0x0000,0x0000,0x0000,0x0012},
	{0x0008,0xF280,0x844F,0x0000,0x0000,0x0000,0x0000,0x001E},
	{0x0008,0xF280,0x84E5,0xC280,0x81CA,0x0000,0x0000,0x0012},
	{0x0000,0x0000,0x0000,0xC280,0x84E5,0x0000,0x0000,0x0006},
	{0x0008,0xF280,0x8564,0xC280,0x83DB,0x0000,0x0000,0x000C},
	{0x0000,0x0000,0x0000,0xC280,0x81CA,0x0000,0x0000,0x000C},
	{0x0008,0xF280,0x8642,0xC280,0x82C8,0x0000,0x0000,0x000C},
	{0x0000,0x0000,0x0000,0xC280,0x84E5,0x0000,0x0000,0x0006},
	{0x0008,0xF280,0x8628,0x0000,0x0000,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0xC280,0x82C8,0x0000,0x0000,0x000C},
	{0x0008,0xF280,0x84E5,0xC480,0x8359,0x0000,0x0000,0x0018},
	{0x0008,0xF280,0x84E5,0xC280,0x8359,0x0000,0x0000,0x000C},
	{0x0008,0xF280,0x8564,0xC280,0x83DB,0x0000,0x0000,0x000C},
	{0x0000,0x0000,0x0000,0xC280,0x82C8,0x0000,0x0000,0x000C},
	{0x0008,0xF280,0x8642,0xC280,0x8359,0x0000,0x0000,0x0012},
	{0x0008,0xF280,0x8628,0xC280,0x8359,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0xC280,0x83DB,0x0000,0x0000,0x000C},
	{0x0000,0x0000,0x0000,0xC280,0x82C8,0x0000,0x0000,0x000C},
	{0x0008,0xF280,0x84E5,0xC280,0x81CA,0x0000,0x0000,0x0012},
	{0x0000,0x0000,0x0000,0xC280,0x84E5,0x0000,0x0000,0x0006},
	{0x0008,0xF280,0x8564,0xC280,0x83DB,0x0000,0x0000,0x000C},
	{0x0000,0x0000,0x0000,0xC280,0x81CA,0x0000,0x0000,0x000C},
	{0x0008,0xF280,0x8642,0xC280,0x82C8,0x0000,0x0000,0x000C},
	{0x0000,0x0000,0x0000,0xC280,0x84E5,0x0000,0x0000,0x0006},
	{0x0008,0xF280,0x8628,0x0000,0x0000,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0xC280,0x82C8,0x0000,0x0000,0x000C},
	{0x0008,0xF280,0x84E5,0xC480,0x8359,0x0000,0x0000,0x0018},
	{0x0008,0xF280,0x84E5,0xC280,0x8359,0x0000,0x0000,0x000C},
	{0x0008,0xF280,0x8564,0xC280,0x83DB,0x0000,0x0000,0x000C},
	{0x0000,0x0000,0x0000,0xC280,0x82C8,0x0000,0x0000,0x000C},
	{0x0008,0xF280,0x8642,0xC280,0x8359,0x0000,0x0000,0x0012},
	{0x0008,0xF280,0x8628,0xC280,0x8359,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0xC280,0x83DB,0x0000,0x0000,0x000C},
	{0x0000,0x0000,0x0000,0xC280,0x82C8,0x0000,0x0000,0x000C},
	{0x0008,0xF280,0x84E5,0xC280,0x81CA,0x9100,0x8036,0x0012},
	{0x0000,0x0000,0x0000,0xC280,0x844F,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x8564,0xC280,0x83DB,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xC280,0x81CA,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x8642,0xC280,0x82C8,0x0000,0x0000,0x000C},
	{0x0000,0x0000,0x0000,0xC280,0x84E5,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x8628,0x0000,0x0000,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0xC280,0x82C8,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x84E5,0xC280,0x8359,0x0000,0x0000,0x000C},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x84E5,0xC280,0x8359,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x8564,0xC280,0x83DB,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xC280,0x82C8,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x8642,0xC280,0x8359,0x0000,0x0000,0x000C},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x8628,0xC280,0x8359,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0xC280,0x83DB,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xC280,0x82C8,0x0000,0x0000,0x000C},
	{0x0008,0xF280,0x84E5,0xC280,0x81CA,0x9100,0x8036,0x0012},
	{0x0000,0x0000,0x0000,0xC280,0x84E5,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x8564,0xC280,0x83DB,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xC280,0x81CA,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x8642,0xC280,0x82C8,0x0000,0x0000,0x000C},
	{0x0000,0x0000,0x0000,0xC280,0x84E5,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x8628,0x0000,0x0000,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0xC280,0x82C8,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x84E5,0xC280,0x8359,0x0000,0x0000,0x000C},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x84E5,0xC280,0x8359,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x8564,0xC280,0x83DB,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xC280,0x82C8,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x8642,0xC280,0x8359,0x0000,0x0000,0x000C},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x8628,0xC280,0x8359,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0xC280,0x83DB,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xC280,0x82C8,0x0000,0x0000,0x000C},
	{0x0008,0xF280,0x84E5,0xC280,0x81CA,0x9200,0x8036,0x0012},
	{0x0000,0x0000,0x0000,0xC280,0x84E5,0x9200,0x8036,0x0006},
	{0x0008,0xF280,0x8564,0xC280,0x83DB,0x9200,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xC280,0x81CA,0x9200,0x8036,0x000C},
	{0x0008,0xF280,0x8642,0xC280,0x82C8,0x0000,0x0000,0x000C},
	{0x0000,0x0000,0x0000,0xC280,0x84E5,0x9200,0x8036,0x0006},
	{0x0008,0xF280,0x8628,0x0000,0x0000,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0xC280,0x82C8,0x9200,0x8033,0x000C},
	{0x0008,0xF280,0x84E5,0xC280,0x8359,0x0000,0x0000,0x000C},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9200,0x8036,0x000C},
	{0x0008,0xF280,0x84E5,0xC280,0x8359,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9200,0x8036,0x0006},
	{0x0008,0xF280,0x8564,0xC280,0x83DB,0x9200,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xC280,0x82C8,0x9200,0x8036,0x000C},
	{0x0008,0xF280,0x8642,0xC280,0x8359,0x0000,0x0000,0x000C},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9200,0x8036,0x0006},
	{0x0008,0xF280,0x8628,0xC280,0x8359,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0xC280,0x83DB,0x9200,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xC280,0x82C8,0x0000,0x0000,0x000C},
	{0x0008,0xF280,0x84E5,0xC280,0x81CA,0x9200,0x8036,0x0012},
	{0x0000,0x0000,0x0000,0xC280,0x84E5,0x9200,0x8036,0x0006},
	{0x0008,0xF280,0x8564,0xC280,0x83DB,0x9200,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xC280,0x81CA,0x9200,0x8036,0x000C},
	{0x0008,0xF280,0x8642,0xC280,0x82C8,0x0000,0x0000,0x000C},
	{0x0000,0x0000,0x0000,0xC280,0x84E5,0x9200,0x8036,0x0006},
	{0x0008,0xF280,0x8628,0x0000,0x0000,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0xC280,0x82C8,0x9200,0x8033,0x000C},
	{0x0008,0xF280,0x84E5,0xC280,0x8359,0x0000,0x0000,0x000C},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9200,0x8036,0x000C},
	{0x0008,0xF280,0x84E5,0xC280,0x8359,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9200,0x8036,0x0006},
	{0x0008,0xF280,0x8564,0xC280,0x83DB,0x9200,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xC280,0x82C8,0x9200,0x8036,0x000C},
	{0x0008,0xF280,0x8642,0xC280,0x8359,0x9200,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9200,0x8036,0x0006},
	{0x0008,0xF280,0x8628,0xC280,0x8359,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0xC280,0x83DB,0x9200,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xC280,0x82C8,0x9200,0x8033,0x000C},
	{0x0008,0xF280,0x84E5,0x0000,0x0000,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x873A,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x8564,0xF280,0x877C,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x8759,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x8642,0xF280,0x876C,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x8759,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x873A,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x8628,0xF280,0x8721,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x84E5,0xF280,0x873A,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x86F7,0x0000,0x0000,0x0012},
	{0x0008,0xF280,0x84E5,0xF280,0x86F7,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x8564,0xF280,0x873A,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x8759,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x8642,0xF280,0x876C,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x8759,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x873A,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x8628,0xF280,0x8721,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x873A,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x84E5,0x0000,0x0000,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x873A,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x8564,0xF280,0x877C,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x8759,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x8642,0xF280,0x876C,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x8759,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x873A,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x8628,0xF280,0x8721,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x84E5,0xF280,0x873A,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x86F7,0x0000,0x0000,0x0012},
	{0x0008,0xF280,0x84E5,0xF280,0x86F7,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x8564,0xF280,0x873A,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x8759,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x8642,0xF280,0x876C,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x8759,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x873A,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x8628,0xF280,0x8721,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x873A,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x84E5,0x0000,0x0000,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x873A,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x8564,0xF280,0x877C,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x8759,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x8642,0xF280,0x876C,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x8759,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x873A,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x8628,0xF280,0x8721,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x84E5,0xF280,0x873A,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x86F7,0x0000,0x0000,0x0012},
	{0x0008,0xF280,0x84E5,0xF280,0x86F7,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x8564,0xF280,0x873A,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x8759,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x8642,0xF280,0x876C,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x8759,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x873A,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x8628,0xF280,0x8721,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x873A,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x84E5,0x0000,0x0000,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x873A,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x8564,0xF280,0x877C,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x8759,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x8642,0xF280,0x876C,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x8759,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x873A,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x8628,0xF280,0x8721,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x84E5,0xF280,0x873A,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x86F7,0x0000,0x0000,0x0012},
	{0x0008,0xF280,0x84E5,0xF280,0x86F7,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x8564,0xF280,0x873A,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x8759,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x8642,0xF280,0x876C,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x8759,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x873A,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x8628,0xF280,0x8721,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x873A,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x8673,0xF180,0x84E5,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x8564,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x86B2,0xF180,0x83DB,0x9100,0x8033,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x83DB,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x8483,0x0000,0x0000,0x0006},
	{0x0008,0xF280,0x8721,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x8483,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x84E5,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x8714,0xF180,0x84E5,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x85AD,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x8673,0xF180,0x8564,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x84E5,0x0000,0x0000,0x000C},
	{0x0008,0xF280,0x8673,0xF180,0x8564,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x86B2,0xF180,0x85AD,0x9100,0x8033,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x85EE,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x8564,0x0000,0x0000,0x0006},
	{0x0008,0xF280,0x8721,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x8564,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x84E5,0x9100,0x8033,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x8714,0xF180,0x8483,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x84B6,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x8673,0xF180,0x84E5,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x84E5,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x8564,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x85AD,0x0000,0x0000,0x0006},
	{0x0008,0xF280,0x86B2,0x0000,0x0000,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x8721,0xF180,0x84E5,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x84E5,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x8564,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x8714,0xF180,0x85AD,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x8673,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x8483,0x0000,0x0000,0x0003},
	{0x0000,0x0000,0x0000,0xF180,0x84B6,0x0000,0x0000,0x0003},
	{0x0000,0x0000,0x0000,0xF180,0x84E5,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x8673,0x0000,0x0000,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x84E5,0x9100,0x8033,0x0006},
	{0x0008,0xF280,0x86B2,0x0000,0x0000,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x81CA,0x0000,0x0000,0x000C},
	{0x0008,0xF280,0x8721,0xF180,0x82C8,0x9100,0x8033,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x82C8,0x9100,0x8033,0x0006},
	{0x0008,0xF280,0x8714,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x81CA,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x81CA,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x8673,0xF180,0x84E5,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x8564,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x86B2,0xF180,0x83DB,0x9100,0x8033,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x83DB,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x8483,0x0000,0x0000,0x0006},
	{0x0008,0xF280,0x8721,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x8483,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x84E5,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x8714,0xF180,0x84E5,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x85AD,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x8673,0xF180,0x8564,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x84E5,0x0000,0x0000,0x000C},
	{0x0008,0xF280,0x8673,0xF180,0x8564,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x86B2,0xF180,0x85AD,0x9100,0x8033,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x85EE,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x8564,0x0000,0x0000,0x0006},
	{0x0008,0xF280,0x8721,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x8564,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x84E5,0x9100,0x8033,0x0006},
	{0x0008,0xF280,0x8714,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x8483,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x84B6,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x8673,0xF180,0x84E5,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x84E5,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x8564,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x85AD,0x0000,0x0000,0x0006},
	{0x0008,0xF280,0x86B2,0x0000,0x0000,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x8721,0xF180,0x84E5,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x84E5,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x8564,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x8714,0xF180,0x85AD,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x8673,0x0000,0x0000,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x84E5,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x84E5,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x8673,0xF180,0x8564,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x85AD,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x86B2,0x0000,0x0000,0x9100,0x8033,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x84E5,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x8564,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x85AD,0x0000,0x0000,0x0006},
	{0x0008,0xF280,0x873A,0xF180,0x84E5,0x9100,0x8036,0x0018},
	{0x0008,0xF180,0x8673,0xF180,0x84E5,0x9100,0x8033,0x0006},
	{0x0008,0xF180,0x869E,0xF180,0x853C,0x0000,0x0000,0x0006},
	{0x0008,0xF180,0x86B2,0xF180,0x8564,0x9100,0x8033,0x0006},
	{0x0008,0xF180,0x86F7,0xF180,0x85EE,0x9100,0x8033,0x0003},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8033,0x0003},
	{0x0008,0xF480,0x8706,0xF180,0x8417,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x8417,0x9100,0x8036,0x000C},
	{0x0008,0xF180,0x86B2,0xF180,0x860C,0x9100,0x8033,0x0006},
	{0x0008,0xF180,0x8673,0x0000,0x0000,0x0000,0x0000,0x0006},
	{0x0008,0xF180,0x860C,0xF180,0x8417,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF480,0x8673,0xF180,0x8417,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x8417,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x860C,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x860C,0xF180,0x8417,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF480,0x865B,0xF180,0x83DB,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x83DB,0x9100,0x8036,0x000C},
	{0x0008,0xF480,0x85EE,0xF180,0x85EE,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x83DB,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF480,0x86F7,0xF180,0x83DB,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x83DB,0x9100,0x8033,0x000C},
	{0x0008,0xF480,0x86E7,0xF180,0x85EE,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x83DB,0x9100,0x8033,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8033,0x0003},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8033,0x0003},
	{0x0008,0xF480,0x86D7,0xF180,0x8359,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x8359,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x85AD,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x869E,0xF180,0x8359,0x9100,0x8033,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8033,0x0006},
	{0x0008,0xF480,0x865B,0xF180,0x83DB,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x83DB,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x85EE,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x86F7,0xF180,0x83DB,0x9100,0x8033,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8033,0x0006},
	{0x0008,0xF180,0x873A,0xF180,0x84E5,0x9100,0x8036,0x0006},
	{0x0008,0xF180,0x872E,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF180,0x873A,0xF180,0x84E5,0x9100,0x8033,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x853C,0x0000,0x0000,0x0006},
	{0x0008,0xF180,0x874F,0xF180,0x8564,0x9100,0x8036,0x0006},
	{0x0008,0xF180,0x873A,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF180,0x874F,0xF180,0x85EE,0x9100,0x8033,0x000C},
	{0x0008,0xF480,0x8759,0xF180,0x8673,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x84E5,0x9100,0x8033,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF180,0x8673,0xF180,0x8564,0x9100,0x8033,0x0006},
	{0x0008,0xF180,0x869E,0x0000,0x0000,0x0000,0x0000,0x0006},
	{0x0008,0xF180,0x86B2,0xF180,0x82C8,0x9100,0x8033,0x0006},
	{0x0008,0xF180,0x86F7,0x0000,0x0000,0x0000,0x0000,0x0006},
	{0x0008,0xF480,0x8706,0xF180,0x8417,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x8417,0x9100,0x8036,0x000C},
	{0x0008,0xF180,0x86B2,0xF180,0x860C,0x9100,0x8033,0x0006},
	{0x0008,0xF180,0x8673,0x0000,0x0000,0x0000,0x0000,0x0006},
	{0x0008,0xF180,0x860C,0xF180,0x8417,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF480,0x8673,0xF180,0x8417,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x8417,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x860C,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x860C,0xF180,0x8417,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF480,0x865B,0xF180,0x83DB,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x83DB,0x9100,0x8036,0x000C},
	{0x0008,0xF480,0x85EE,0xF180,0x85EE,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x83DB,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF480,0x86F7,0xF180,0x83DB,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x83DB,0x9100,0x8036,0x000C},
	{0x0008,0xF480,0x86E7,0xF180,0x85EE,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x83DB,0x9100,0x8033,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8033,0x0006},
	{0x0008,0xF480,0x86D7,0xF180,0x8359,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x8359,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x85AD,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x869E,0xF180,0x8359,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF480,0x865B,0xF180,0x83DB,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x83DB,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x85EE,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x86F7,0xF180,0x83DB,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x8759,0xF180,0x84E5,0x9100,0x8036,0x000C},
	{0x0008,0xF180,0x876C,0xF180,0x8673,0x9100,0x8036,0x0006},
	{0x0008,0xF180,0x8759,0xF180,0x84E5,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x874F,0xF180,0x853C,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x8721,0xF180,0x869E,0x9100,0x8033,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x853C,0x0000,0x0000,0x0006},
	{0x0008,0xF480,0x873A,0xF180,0x8564,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x86B2,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x8564,0x9100,0x8036,0x0006},
	{0x0008,0xF180,0x873A,0xF180,0x85AD,0x9100,0x8033,0x0006},
	{0x0008,0xF180,0x874F,0x0000,0x0000,0x0000,0x0000,0x0006},
	{0x0008,0xF180,0x8759,0xF180,0x86D7,0x9100,0x8033,0x0006},
	{0x0008,0xF180,0x877C,0xF180,0x86D7,0x0000,0x0000,0x0006},
	{0x0008,0xF480,0x8783,0xF180,0x8417,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x8417,0x9100,0x8036,0x000C},
	{0x0008,0xF180,0x8759,0xF180,0x860C,0x9100,0x8033,0x0006},
	{0x0008,0xF180,0x873A,0x0000,0x0000,0x0000,0x0000,0x0006},
	{0x0008,0xF180,0x8706,0xF180,0x8417,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF480,0x873A,0xF180,0x8417,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x8417,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x860C,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x8706,0xF180,0x8417,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF480,0x872E,0xF180,0x83DB,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x83DB,0x9100,0x8036,0x000C},
	{0x0008,0xF480,0x86F7,0xF180,0x85EE,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x83DB,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF480,0x877C,0xF180,0x83DB,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x83DB,0x9100,0x8033,0x000C},
	{0x0008,0xF480,0x8774,0xF180,0x85EE,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x83DB,0x9100,0x8033,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8033,0x0006},
	{0x0008,0xF480,0x876C,0xF180,0x8359,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x8359,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x85AD,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x874F,0xF180,0x8359,0x9100,0x8033,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8033,0x0006},
	{0x0008,0xF480,0x872E,0xF180,0x83DB,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x83DB,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x85EE,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x877C,0xF180,0x83DB,0x9100,0x8033,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8033,0x0006},
	{0x0008,0xF180,0x879D,0xF180,0x84E5,0x9100,0x8036,0x0006},
	{0x0008,0xF180,0x8797,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF180,0x879D,0xF180,0x84E5,0x9100,0x8033,0x0006},
	{0x0000,0x0000,0x0000,0xF180,0x853C,0x0000,0x0000,0x0006},
	{0x0008,0xF180,0x87A8,0xF180,0x8564,0x9100,0x8036,0x0006},
	{0x0008,0xF180,0x879D,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF180,0x87A8,0xF180,0x85EE,0x9100,0x8033,0x000C},
	{0x0008,0xF480,0x87AD,0xF180,0x84E5,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x84E5,0x9100,0x8033,0x000C},
	{0x0008,0xF180,0x873A,0xF180,0x8673,0x9100,0x8033,0x0006},
	{0x0008,0xF180,0x874F,0x0000,0x0000,0x0000,0x0000,0x0006},
	{0x0008,0xF180,0x8759,0xF180,0x84E5,0x9100,0x8033,0x0006},
	{0x0008,0xF180,0x877C,0x0000,0x0000,0x0000,0x0000,0x0006},
	{0x0008,0xF480,0x8783,0xF180,0x8417,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x8417,0x9100,0x8036,0x000C},
	{0x0008,0xF180,0x8759,0xF180,0x860C,0x9100,0x8033,0x0006},
	{0x0008,0xF180,0x873A,0x0000,0x0000,0x0000,0x0000,0x0006},
	{0x0008,0xF180,0x8706,0xF180,0x8417,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF480,0x873A,0xF180,0x8417,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x8417,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x860C,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x8706,0xF180,0x8417,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF480,0x872E,0xF180,0x83DB,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x83DB,0x9100,0x8036,0x000C},
	{0x0008,0xF480,0x86F7,0xF180,0x85EE,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x83DB,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF480,0x877C,0xF180,0x83DB,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x83DB,0x9100,0x8033,0x000C},
	{0x0008,0xF480,0x8774,0xF180,0x85EE,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x83DB,0x9100,0x8033,0x000C},
	{0x0008,0xF480,0x876C,0xF180,0x8359,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x8359,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x85AD,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x874F,0xF180,0x8359,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF480,0x872E,0xF180,0x83DB,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x83DB,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x85EE,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xF180,0x83DB,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0xC759,0xF380,0xC791,0x9100,0x8033,0x0012},
	{0x0008,0xF280,0xC759,0xF380,0xC791,0x9100,0x8036,0x0012},
	{0x0008,0xF280,0xC759,0xF380,0xC791,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0xC759,0xF380,0xC791,0x9100,0x8036,0x0018},
	{0x0008,0xF280,0x8759,0xF380,0x8797,0x9100,0x8033,0x0018},
	{0x0008,0xF380,0x874F,0xF280,0x844F,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x8628,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x873A,0xF280,0x844F,0x9100,0x8033,0x000C},
	{0x0008,0xF180,0x872E,0xF280,0x8628,0x9100,0x8036,0x0006},
	{0x0008,0xF380,0x873A,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x844F,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x8628,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x872E,0xF280,0x844F,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x8714,0xF280,0x8628,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x8714,0xF280,0x844F,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x872E,0xF280,0x8628,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x8714,0xF280,0x844F,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x86F7,0xF280,0x8628,0x9100,0x8036,0x0006},
	{0x0008,0xF380,0x869E,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x844F,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x8628,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x865B,0xF280,0x844F,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x8673,0xF280,0x8628,0x9100,0x8033,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8033,0x0006},
	{0x0008,0xF380,0x869E,0xF280,0x83DB,0x9100,0x8037,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x85EE,0x9100,0x8037,0x0006},
	{0x0008,0xF380,0x869E,0x0000,0x0000,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x83DB,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x86C5,0xF280,0x85EE,0x9100,0x8037,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8037,0x0006},
	{0x0008,0xF280,0x869E,0xF280,0x83DB,0x9100,0x8037,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x85EE,0x9100,0x8037,0x000C},
	{0x0008,0xF280,0x8714,0xF280,0x83DB,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x86E7,0xF280,0x85EE,0x9100,0x8037,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8037,0x0006},
	{0x0008,0xF280,0x8706,0xF280,0x8417,0x9100,0x8037,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x860C,0x9100,0x8037,0x0006},
	{0x0008,0xF280,0x8706,0x0000,0x0000,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x8417,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x8714,0xF280,0x860C,0x9100,0x8037,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8037,0x0006},
	{0x0008,0xF280,0x872E,0xF280,0x8417,0x9100,0x8037,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x860C,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x8714,0xF280,0x8417,0x9100,0x8037,0x000C},
	{0x0008,0xF280,0x872E,0xF280,0x860C,0x9100,0x8033,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x844F,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x874F,0xF280,0x8628,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x873A,0xF280,0x844F,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x872E,0xF280,0x8628,0x9100,0x8036,0x0006},
	{0x0008,0xF380,0x873A,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x844F,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x8628,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x872E,0xF280,0x844F,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x8714,0xF280,0x8628,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x8714,0xF280,0x84B6,0x9100,0x8035,0x000C},
	{0x0008,0xF280,0x872E,0xF280,0x865B,0x9100,0x8035,0x000C},
	{0x0008,0xF280,0x8714,0xF280,0x84B6,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x86F7,0xF280,0x865B,0x9100,0x8035,0x0006},
	{0x0008,0xF380,0x869E,0x0000,0x0000,0x9100,0x8035,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x84B6,0x9100,0x8035,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x865B,0x9100,0x8035,0x000C},
	{0x0008,0xF280,0x865B,0xF280,0x84B6,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x8673,0xF280,0x865B,0x9100,0x8035,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8035,0x0006},
	{0x0008,0xF380,0x869E,0xF280,0x8312,0x9100,0x8037,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x8589,0x9100,0x8037,0x0006},
	{0x0008,0xF380,0x869E,0x0000,0x0000,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x8312,0x9100,0x8033,0x000C},
	{0x0008,0xF380,0x86C5,0xF280,0x8589,0x9100,0x8037,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8037,0x0006},
	{0x0008,0xF280,0x869E,0xF280,0x8312,0x9100,0x8037,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x8589,0x9100,0x8037,0x000C},
	{0x0008,0xF280,0x8714,0xF280,0x8312,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x86E7,0xF280,0x839C,0x9100,0x8037,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8037,0x0006},
	{0x0008,0xF280,0x86F7,0xF280,0x83DB,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x85EE,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x86F7,0x0000,0x0000,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x83DB,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x8714,0xF280,0x85EE,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x872E,0xF280,0x83DB,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x85EE,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x8714,0xF280,0x83DB,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x86F7,0xF280,0x85EE,0x9100,0x8033,0x000C},
	{0x0008,0xF380,0x874F,0xF280,0x844F,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x8628,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x873A,0xF280,0x844F,0x9100,0x8033,0x000C},
	{0x0008,0xF180,0x872E,0xF280,0x8628,0x9100,0x8036,0x0006},
	{0x0008,0xF380,0x873A,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x844F,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x8628,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x872E,0xF280,0x844F,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x8714,0xF280,0x8628,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x8714,0xF280,0x844F,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x872E,0xF280,0x8628,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x8714,0xF280,0x844F,0x9100,0x8033,0x000C},
	{0x0008,0xF180,0x86F7,0xF280,0x8628,0x9100,0x8036,0x0006},
	{0x0008,0xF380,0x869E,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x844F,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x8628,0x9100,0x8036,0x000C},
	{0x0008,0xF380,0x865B,0xF280,0x844F,0x9100,0x8033,0x000C},
	{0x0008,0xF380,0x8673,0xF280,0x8628,0x9100,0x8033,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8033,0x0006},
	{0x0008,0xF380,0x869E,0xF280,0x83DB,0x9100,0x8037,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x85EE,0x9100,0x8037,0x0006},
	{0x0008,0xF380,0x869E,0x0000,0x0000,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x83DB,0x9100,0x8033,0x000C},
	{0x0008,0xF380,0x86C5,0xF280,0x85EE,0x9100,0x8037,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8037,0x0006},
	{0x0008,0xF280,0x869E,0xF280,0x83DB,0x9100,0x8037,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x85EE,0x9100,0x8037,0x000C},
	{0x0008,0xF280,0x8714,0xF280,0x83DB,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x86E7,0xF280,0x85EE,0x9100,0x8037,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8037,0x0006},
	{0x0008,0xF380,0x8706,0xF280,0x8417,0x9100,0x8037,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x860C,0x9100,0x8037,0x0006},
	{0x0008,0xF380,0x8706,0x0000,0x0000,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x8417,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x8714,0xF280,0x860C,0x9100,0x8037,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8037,0x0006},
	{0x0008,0xF280,0x872E,0xF280,0x8417,0x9100,0x8037,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x860C,0x9100,0x8037,0x000C},
	{0x0008,0xF280,0x8714,0xF280,0x8417,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x872E,0xF280,0x860C,0x9100,0x8033,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8033,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x844F,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x874F,0xF280,0x8628,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x873A,0xF280,0x844F,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x872E,0xF280,0x8628,0x9100,0x8036,0x0006},
	{0x0008,0xF380,0x873A,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x844F,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x8628,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x872E,0xF280,0x844F,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x8714,0xF280,0x8628,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x8714,0xF280,0x84B6,0x9100,0x8035,0x000C},
	{0x0008,0xF280,0x872E,0xF280,0x865B,0x9100,0x8035,0x000C},
	{0x0008,0xF280,0x8714,0xF280,0x84B6,0x9100,0x8033,0x000C},
	{0x0008,0xF180,0x86F7,0xF280,0x865B,0x9100,0x8035,0x0006},
	{0x0008,0xF380,0x869E,0x0000,0x0000,0x9100,0x8035,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x84B6,0x9100,0x8035,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x865B,0x9100,0x8035,0x000C},
	{0x0008,0xF280,0x865B,0xF280,0x84B6,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x8673,0xF280,0x865B,0x9100,0x8033,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8033,0x0006},
	{0x0008,0xF280,0x869E,0xF280,0x8312,0x9100,0x8037,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x8589,0x9100,0x8037,0x0006},
	{0x0008,0xF280,0x869E,0x0000,0x0000,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x8312,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x86C5,0xF280,0x8589,0x9100,0x8037,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8037,0x0006},
	{0x0008,0xF280,0x869E,0xF280,0x8312,0x9100,0x8037,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x8589,0x9100,0x8037,0x000C},
	{0x0008,0xF280,0x8714,0xF280,0x8312,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x86E7,0xF280,0x839C,0x9100,0x8033,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8033,0x0006},
	{0x0008,0xF280,0x86F7,0xF280,0x83DB,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x85EE,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x86F7,0x0000,0x0000,0x0000,0x0000,0x0006},
	{0x0000,0x0000,0x0000,0xF280,0x83DB,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x8714,0xF280,0x85EE,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0006},
	{0x0008,0xF280,0x872E,0xF280,0x83DB,0x9100,0x8036,0x000C},
	{0x0000,0x0000,0x0000,0xF280,0x85EE,0x9100,0x8036,0x000C},
	{0x0008,0xF280,0x8714,0xF280,0x83DB,0x9100,0x8033,0x000C},
	{0x0008,0xF280,0x86F7,0xF280,0x85EE,0x9100,0x8036,0x0006},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0003},
	{0x0000,0x0000,0x0000,0x0000,0x0000,0x9100,0x8036,0x0003}
};
