/* Andrew Wilder
 * Fall 2014
 */

// Defines for the interrupt handler
#define REG_IE        *(volatile unsigned short*) 0x4000200
#define REG_IF        *(volatile unsigned short*) 0x4000202
#define REG_IME       *(volatile unsigned short*) 0x4000208
#define IRQ_ENABLE    1
#define IRQ_VBLANK    (1 << 0)
#define IRQ_HBLANK    (1 << 1)
#define IRQ_VCOUNT    (1 << 2)
#define IRQ_TIMER(n)  (1 << (3 + (n)))
#define IRQ_COM       (1 << 7)
#define IRQ_DMA(n)    (1 << (8 + (n)))
#define IRQ_KEYPAD    (1 << 12)
#define IRQ_CARTRIDGE (1 << 13)
typedef void (*irqptr)(void);
#define REG_ISR_MAIN *(irqptr*) 0x3007FFC

// Defines for the timer
#define REG_TMD(n)   *(volatile unsigned short*) (0x4000100 + ((n) << 2))
#define REG_TMCNT(n) *(volatile unsigned short*) (0x4000102 + ((n) << 2))
#define TM_FREQ_1    0
#define TM_FREQ_64   1
#define TM_FREQ_256  2
#define TM_FREQ_1024 3
#define TM_CASCADE   (1 << 2)
#define TM_IRQ       (1 << 6)
#define TM_ENABLE    (1 << 7)

// Defines for sound control
#define REG_SND1SWP   *(volatile unsigned short*) 0x4000060 
#define REG_SND1ENV   *(volatile unsigned short*) 0x4000062
#define REG_SND1FRQ   *(volatile unsigned short*) 0x4000064
#define REG_SND2ENV   *(volatile unsigned short*) 0x4000068
#define REG_SND2FRQ   *(volatile unsigned short*) 0x400006C
#define REG_SND4ENV   *(volatile unsigned short*) 0x4000078
#define REG_SND4FRQ   *(volatile unsigned short*) 0x400007C
#define REG_SNDDMGCNT *(volatile unsigned short*) 0x4000080
#define REG_SNDSTAT   *(volatile unsigned short*) 0x4000084
#define MASTER_SND_EN (1 << 7)
#define MASTER_VOL25  0
#define MASTER_VOL50  1
#define MASTER_VOL100 2
#define LEFT_VOL(n)   (n)
#define RIGHT_VOL(n)  ((n) << 4)
#define CHAN_EN_L(n)  (1 << ((n) + 7))
#define CHAN_EN_R(n)  (1 << ((n) + 11))

// Defines and global variables used by the music handler
typedef struct {
	unsigned short CH1_SWP;
	unsigned short CH1_ENV;
	unsigned short CH1_FRQ;
	unsigned short CH2_ENV;
	unsigned short CH2_FRQ;
	unsigned short CH4_ENV;
	unsigned short CH4_FRQ;
	unsigned short length;
} note_t;
void initMusic();
void playMusic();
void playNote(int);
#define LENGTH 420
#define BPM 177
#define QUANTIZATION 24
#define BPM_QUAN_TRANSFORM(b,q) -(0x3C0000/((b)*(q)))
int index;
int wait;

const note_t sound_data[LENGTH];
//void printNote(const note_t *n, int index);

/**
 * Initialize all the data required by the music hander and sound registers.
 */
void initMusic() {
	REG_IME = REG_IME & ~IRQ_ENABLE;
	REG_ISR_MAIN = playMusic;
	REG_IE = IRQ_TIMER(0);

	REG_TMD(0) = BPM_QUAN_TRANSFORM(BPM, QUANTIZATION);

	REG_TMCNT(0) = TM_ENABLE | TM_IRQ | TM_FREQ_1024;

	REG_SNDSTAT = MASTER_SND_EN;
	REG_SNDDMGCNT = CHAN_EN_L(1) | CHAN_EN_R(1)
	                | CHAN_EN_L(2) | CHAN_EN_R(2) 
	                | CHAN_EN_L(4) | CHAN_EN_R(4)
	                | LEFT_VOL(7) | RIGHT_VOL(7);

	index = 0;
	wait = 1;

	//Enable Interrupts
	REG_IME = IRQ_ENABLE;
}

/**
 * Play one 48th of a measure of music.
 */
void playMusic() {
	REG_IME &= ~IRQ_ENABLE;

	switch(REG_IF) {
		case IRQ_TIMER(0):
                if(!--wait) {
                	//printNote(sound_data + index, index);

                	if(sound_data[index].CH1_FRQ) {
                		REG_SND1SWP = sound_data[index].CH1_SWP;

                		REG_SND1ENV = sound_data[index].CH1_ENV;

                		REG_SND1FRQ = sound_data[index].CH1_FRQ;
                	}

                	if(sound_data[index].CH2_FRQ) {
                	

                		REG_SND2ENV = sound_data[index].CH2_ENV;

                		REG_SND2FRQ = sound_data[index].CH2_FRQ;
                	}
                	if(sound_data[index].CH4_FRQ) {
                		

                		REG_SND4ENV = sound_data[index].CH4_ENV;

                		REG_SND4FRQ = sound_data[index].CH4_FRQ;
                	}
                	wait = sound_data[index].length;
                	if(++index == LENGTH) {
                		index = 1;
                	}
                }
		    
		

	}

	REG_IF = REG_IF;
	REG_IME = IRQ_ENABLE;

}



// Note data
const note_t sound_data[LENGTH] = {
	{0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0F00, 0x8002, 24},
	{0x0000, 0x2040, 0x8417, 0x841F, 0x865B, 0xF700, 0x8002, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8642, 0x0000, 0x0000, 6 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8689, 0x0000, 0x0000, 6 },
	{0x0000, 0x2040, 0x839C, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8642, 0x0000, 0x0000, 6 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8689, 0x0000, 0x0000, 6 },
	{0x0000, 0x2040, 0x8312, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8642, 0x0000, 0x0000, 6 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8689, 0x0000, 0x0000, 6 },
	{0x0000, 0x2040, 0x82C8, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8642, 0x0000, 0x0000, 6 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0065, 0x2940, 0x82C8, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8689, 0x0000, 0x0000, 6 },
	{0x0000, 0xF840, 0x860C, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0xF31F, 0x8051, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8642, 0x0000, 0x0000, 6 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0xF840, 0x8689, 0x841F, 0x865B, 0xF31F, 0x8051, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8642, 0x0000, 0x0000, 6 },
	{0x0000, 0xF840, 0x865B, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0xF31F, 0x8051, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8642, 0x0000, 0x0000, 6 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0xF840, 0x86E7, 0x841F, 0x865B, 0xF31F, 0x8051, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0xF840, 0x86C5, 0x841F, 0x8642, 0x0000, 0x0000, 6 },
	{0x0000, 0xF840, 0x86B2, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0xF31F, 0x8051, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0xF840, 0x860C, 0x841F, 0x8642, 0x0000, 0x0000, 6 },
	{0x0000, 0xF840, 0x86B2, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0xF31F, 0x8051, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0xF840, 0x8689, 0x841F, 0x8642, 0x0000, 0x0000, 6 },
	{0x0000, 0xF840, 0x865B, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0xF840, 0x8642, 0x841F, 0x865B, 0xF31F, 0x8051, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8642, 0x0000, 0x0000, 6 },
	{0x0000, 0xF840, 0x860C, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x865B, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0xF804, 0x85EE, 0x841F, 0x865B, 0xF31F, 0x8051, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8564, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0x841F, 0x8642, 0x0000, 0x0000, 6 },
	{0x0000, 0xF740, 0x860C, 0xF400, 0x860C, 0xD31F, 0x8051, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x865B, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86B2, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x2040, 0x8417, 0xF400, 0x86B2, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86B2, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86C5, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86C5, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86C5, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86C5, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86B2, 0xD31F, 0x8051, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x865B, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x869E, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x8642, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x2040, 0x83DB, 0xF400, 0x86D7, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x869E, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x8689, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86C5, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x2040, 0x8417, 0xF400, 0x860C, 0xD31F, 0x8051, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x865B, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86B2, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86B2, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86B2, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86C5, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86C5, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86C5, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86C5, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86B2, 0xD31F, 0x8051, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x865B, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x869E, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x8642, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x2040, 0x83DB, 0xF400, 0x86D7, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x869E, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x8689, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 3 },
	{0x0000, 0x2740, 0x83DB, 0x0000, 0x0000, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 3 },
	{0x0000, 0xF400, 0x860C, 0xA380, 0x8417, 0xD200, 0xC061, 3 },
	{0x0000, 0xF400, 0x865B, 0xA380, 0x84B6, 0x0000, 0x0000, 3 },
	{0x0000, 0xF400, 0x86B2, 0xA380, 0x8564, 0xD200, 0xC051, 3 },
	{0x0000, 0xF400, 0x860C, 0xA380, 0x8417, 0x0000, 0x0000, 3 },
	{0x0000, 0xF400, 0x86B2, 0xA380, 0x8564, 0xD200, 0xC061, 3 },
	{0x0000, 0xF400, 0x860C, 0xA380, 0x8417, 0x0000, 0x0000, 3 },
	{0x0000, 0xF400, 0x86B2, 0xA380, 0x8564, 0xD200, 0xC051, 3 },
	{0x0000, 0xF400, 0x860C, 0xA380, 0x8417, 0x0000, 0x0000, 3 },
	{0x0000, 0xF400, 0x86C5, 0xA380, 0x8589, 0xD200, 0xC061, 3 },
	{0x0000, 0xF400, 0x860C, 0xA380, 0x8417, 0x0000, 0x0000, 3 },
	{0x0000, 0xF400, 0x86C5, 0xA380, 0x8589, 0xD200, 0xC051, 3 },
	{0x0000, 0xF400, 0x860C, 0xA380, 0x8417, 0x0000, 0x0000, 3 },
	{0x0000, 0xF400, 0x86C5, 0xA380, 0x8589, 0xD200, 0xC061, 3 },
	{0x0000, 0xF400, 0x860C, 0xA380, 0x8417, 0x0000, 0x0000, 3 },
	{0x0000, 0xF400, 0x86C5, 0xA380, 0x8589, 0xD200, 0xC051, 3 },
	{0x0000, 0xF400, 0x860C, 0xA380, 0x8417, 0x0000, 0x0000, 3 },
	{0x0000, 0xF400, 0x86B2, 0xA380, 0x8564, 0xD200, 0xC061, 3 },
	{0x0000, 0xF400, 0x860C, 0xA380, 0x8417, 0x0000, 0x0000, 3 },
	{0x0000, 0xF400, 0x865B, 0xA380, 0x84B6, 0xD200, 0xC051, 3 },
	{0x0000, 0xF400, 0x860C, 0xA380, 0x8417, 0x0000, 0x0000, 3 },
	{0x0000, 0xF400, 0x869E, 0xA380, 0x853C, 0xD200, 0xC061, 3 },
	{0x0000, 0xF400, 0x860C, 0xA380, 0x8417, 0x0000, 0x0000, 3 },
	{0x0000, 0xF400, 0x8642, 0xA380, 0x8483, 0xD200, 0xC051, 3 },
	{0x0000, 0xF400, 0x860C, 0xA380, 0x8417, 0x0000, 0x0000, 3 },
	{0x0000, 0xF400, 0x86D7, 0xA380, 0x85AD, 0xD200, 0xC061, 3 },
	{0x0000, 0xF400, 0x860C, 0xA380, 0x8417, 0x0000, 0x0000, 3 },
	{0x0000, 0xF400, 0x869E, 0xA380, 0x853C, 0xD200, 0xC051, 3 },
	{0x0000, 0xF400, 0x860C, 0xA380, 0x8417, 0x0000, 0x0000, 3 },
	{0x0000, 0xF400, 0x8689, 0xA380, 0x8512, 0xD200, 0xC061, 3 },
	{0x0000, 0xF400, 0x860C, 0xA380, 0x8417, 0x0000, 0x0000, 3 },
	{0x0000, 0xF400, 0x86C5, 0xA380, 0x8589, 0xD200, 0xC051, 3 },
	{0x0000, 0xF400, 0x860C, 0xA380, 0x8417, 0x0000, 0x0000, 3 },
	{0x001B, 0x8280, 0xC689, 0xF400, 0x860C, 0xD200, 0xC061, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x865B, 0x0000, 0x0000, 3 },
	{0x001B, 0x8280, 0xC689, 0xF400, 0x86B2, 0xD200, 0xC051, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x001B, 0x9280, 0xC689, 0xF400, 0x86B2, 0xD200, 0xC061, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x001B, 0x9280, 0xC689, 0xF400, 0x86B2, 0xD200, 0xC051, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x001B, 0xA280, 0xC689, 0xF400, 0x86C5, 0xD200, 0xC061, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x001B, 0xA280, 0xC689, 0xF400, 0x86C5, 0xD200, 0xC051, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x001B, 0xB280, 0xC689, 0xF400, 0x86C5, 0xD200, 0xC061, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x001B, 0xB280, 0xC689, 0xF400, 0x86C5, 0xD200, 0xC051, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x001B, 0xC280, 0xC689, 0xF400, 0x86B2, 0xD200, 0xC061, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x001B, 0xC280, 0xC689, 0xF400, 0x865B, 0xD200, 0xC051, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x001B, 0xD280, 0xC689, 0xF400, 0x869E, 0xD200, 0xC061, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x001B, 0xD280, 0xC689, 0xF400, 0x8642, 0xD200, 0xC051, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x002B, 0xF1A6, 0xC642, 0xF400, 0x86D7, 0xD200, 0xC061, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 1 },
	{0x002B, 0xF1A6, 0xC642, 0x0000, 0x0000, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x869E, 0xD200, 0xC051, 2 },
	{0x002B, 0xF1A6, 0xC642, 0xF400, 0x86D7, 0x0000, 0x0000, 1 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x001C, 0xF4A5, 0x85AD, 0xF400, 0x8689, 0xD200, 0xC061, 3 },
	{0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 3 },
	{0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 3 },
	{0x0000, 0xB200, 0x860C, 0x0000, 0x0000, 0x0000, 0x0000, 6 },
	{0x0000, 0xB200, 0x86B2, 0x0000, 0x0000, 0x0000, 0x0000, 6 },
	{0x0000, 0xB200, 0x8642, 0x0000, 0x0000, 0x0000, 0x0000, 6 },
	{0x0000, 0xB200, 0x86B2, 0x0000, 0x0000, 0x0000, 0x0000, 3 },
	{0x0000, 0xB200, 0x8642, 0x0000, 0x0000, 0x0000, 0x0000, 3 },
	{0x0000, 0xB200, 0x865B, 0x0000, 0x0000, 0x0000, 0x0000, 6 },
	{0x0000, 0xB200, 0x8689, 0x0000, 0x0000, 0x0000, 0x0000, 2 },
	{0x0000, 0xB200, 0x86B2, 0x0000, 0x0000, 0x0000, 0x0000, 2 },
	{0x0000, 0xB200, 0x86C5, 0x0000, 0x0000, 0x0000, 0x0000, 2 },
	{0x0000, 0xB200, 0x86B2, 0x0000, 0x0000, 0x0000, 0x0000, 4 },
	{0x0000, 0xB200, 0x860C, 0x0000, 0x0000, 0x0000, 0x0000, 2 },
	{0x007F, 0xE200, 0x86E7, 0x0000, 0x0000, 0xD31F, 0x8051, 6 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x8706, 0xA21F, 0x8041, 2 },
	{0x0000, 0x0000, 0x0000, 0xF428, 0xC6B2, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86B2, 0x0000, 0x0000, 2 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x8721, 0xA21F, 0x8041, 4 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86C5, 0x0000, 0x0000, 2 },
	{0x003B, 0xD280, 0x8278, 0xF428, 0xC72E, 0xA21F, 0x8041, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x872E, 0x0000, 0x0000, 4 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x872E, 0xA21F, 0x8041, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x8721, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x8706, 0x0000, 0x0000, 2 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x86E7, 0xA21F, 0x8041, 2 },
	{0x0000, 0x0000, 0x0000, 0xF428, 0xC689, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x8689, 0x0000, 0x0000, 2 },
	{0x004C, 0xD280, 0x86E7, 0xF400, 0x86C5, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x8689, 0x0000, 0x0000, 3 },
	{0x001C, 0xF4A5, 0x85AD, 0xF400, 0x86B2, 0xA21F, 0x8041, 6 },
	{0x002B, 0xF1A6, 0xC642, 0x0000, 0x0000, 0xA21F, 0x8041, 2 },
	{0x002B, 0xF1A6, 0xC642, 0x0000, 0x0000, 0x0000, 0x0000, 2 },
	{0x002B, 0xF1A6, 0xC642, 0x0000, 0x0000, 0x0000, 0x0000, 2 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x860C, 0xA21F, 0x8041, 6 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x86B2, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x86B2, 0xA21F, 0x8041, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x865B, 0x0000, 0x0000, 2 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x86B2, 0xA21F, 0x8041, 6 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x865B, 0xA21F, 0x8041, 6 },
	{0x004C, 0xD280, 0x86E7, 0xF400, 0x8689, 0xA21F, 0x8041, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86B2, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86C5, 0x0000, 0x0000, 2 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x86B2, 0xA21F, 0x8041, 4 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x865B, 0x0000, 0x0000, 2 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x86E7, 0xA21F, 0x8041, 6 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x8706, 0xA21F, 0x8041, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86B2, 0x0000, 0x0000, 4 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x8721, 0xA21F, 0x8041, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86C5, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x872E, 0x0000, 0x0000, 2 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x8759, 0xA21F, 0x8041, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x872E, 0x0000, 0x0000, 4 },
	{0x003B, 0xD280, 0x8278, 0xF428, 0xC721, 0xA21F, 0x8041, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x8721, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86E7, 0x0000, 0x0000, 2 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x8706, 0xA21F, 0x8041, 6 },
	{0x003B, 0xD280, 0x8278, 0x0000, 0x0000, 0xA21F, 0x8041, 4 },
	{0x002B, 0xB1A6, 0xC642, 0x0000, 0x0000, 0x0000, 0x0000, 2 },
	{0x003B, 0xD280, 0x8278, 0x0000, 0x0000, 0xA21F, 0x8041, 4 },
	{0x002B, 0xB1A6, 0xC642, 0x0000, 0x0000, 0x0000, 0x0000, 2 },
	{0x003B, 0xD280, 0x8278, 0x0000, 0x0000, 0xA21F, 0x8041, 2 },
	{0x002B, 0xB1A6, 0xC642, 0x0000, 0x0000, 0x0000, 0x0000, 2 },
	{0x002B, 0xB1A6, 0xC642, 0x0000, 0x0000, 0x0000, 0x0000, 2 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x860C, 0xA21F, 0x8041, 6 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x86B2, 0xA21F, 0x8041, 4 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 2 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x86C5, 0xA21F, 0x8041, 4 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 2 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x86B2, 0xA21F, 0x8041, 6 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x865B, 0xA21F, 0x8041, 6 },
	{0x004C, 0xD280, 0x86E7, 0xF400, 0x8689, 0xA21F, 0x8041, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86B2, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86C5, 0x0000, 0x0000, 2 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x86B2, 0xA21F, 0x8041, 4 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x865B, 0x0000, 0x0000, 2 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x86E7, 0xA21F, 0x8041, 6 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x8706, 0xA21F, 0x8041, 2 },
	{0x0000, 0x0000, 0x0000, 0xF428, 0xC6B2, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86B2, 0x0000, 0x0000, 2 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x8721, 0xA21F, 0x8041, 4 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86C5, 0x0000, 0x0000, 2 },
	{0x003B, 0xD280, 0x8278, 0xF428, 0xC745, 0xA21F, 0x8041, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x8745, 0x0000, 0x0000, 4 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x872E, 0xA21F, 0x8041, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x8721, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x8706, 0x0000, 0x0000, 2 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x86E7, 0xA21F, 0x8041, 2 },
	{0x0000, 0x0000, 0x0000, 0xF428, 0xC689, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x8689, 0x0000, 0x0000, 2 },
	{0x004C, 0xD280, 0x86E7, 0xF400, 0x86C5, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x8689, 0x0000, 0x0000, 3 },
	{0x001C, 0xF4A5, 0x85AD, 0xF400, 0x86B2, 0xA21F, 0x8041, 6 },
	{0x002B, 0xF1A6, 0xC642, 0x0000, 0x0000, 0xA21F, 0x8041, 2 },
	{0x002B, 0xF1A6, 0xC642, 0x0000, 0x0000, 0x0000, 0x0000, 2 },
	{0x002B, 0xF1A6, 0xC642, 0x0000, 0x0000, 0x0000, 0x0000, 2 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x860C, 0xA21F, 0x8041, 6 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x86B2, 0xA21F, 0x8041, 3 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 3 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x86B2, 0xA21F, 0x8041, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x860C, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x865B, 0x0000, 0x0000, 2 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x86B2, 0xA21F, 0x8041, 6 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x865B, 0xA21F, 0x8041, 6 },
	{0x004C, 0xD280, 0x86E7, 0xF400, 0x8689, 0xA21F, 0x8041, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86B2, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86C5, 0x0000, 0x0000, 2 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x86B2, 0xA21F, 0x8041, 4 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x865B, 0x0000, 0x0000, 2 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x86E7, 0xA21F, 0x8041, 6 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x8706, 0xA21F, 0x8041, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86B2, 0x0000, 0x0000, 4 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x8721, 0xA21F, 0x8041, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86C5, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x872E, 0x0000, 0x0000, 2 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x8759, 0xA21F, 0x8041, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x872E, 0x0000, 0x0000, 4 },
	{0x003B, 0xD280, 0x8278, 0xF428, 0xC721, 0xA21F, 0x8041, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x8721, 0x0000, 0x0000, 2 },
	{0x0000, 0x0000, 0x0000, 0xF400, 0x86E7, 0x0000, 0x0000, 2 },
	{0x003B, 0xD280, 0x8278, 0xF400, 0x8706, 0xA21F, 0x8041, 6 },
	{0x003B, 0xD280, 0x8278, 0x0000, 0x0000, 0xA21F, 0x8041, 4 },
	{0x002B, 0xB1A6, 0xC642, 0x0000, 0x0000, 0x0000, 0x0000, 2 },
	{0x003B, 0xD280, 0x8278, 0x0000, 0x0000, 0xA21F, 0x8041, 2 },
	{0x002B, 0xB1A6, 0xC642, 0x0000, 0x0000, 0x0000, 0x0000, 1 },
	{0x002B, 0xB1A6, 0xC642, 0x0000, 0x0000, 0x0000, 0x0000, 1 },
	{0x002B, 0xB1A6, 0xC642, 0x0000, 0x0000, 0x0000, 0x0000, 2 },
	{0x003B, 0xD280, 0x8278, 0x0000, 0x0000, 0xA21F, 0x8041, 2 },
	{0x002B, 0xB1A6, 0xC642, 0x0000, 0x0000, 0x0000, 0x0000, 2 },
	{0x002B, 0xB1A6, 0xC642, 0x0000, 0x0000, 0x0000, 0x0000, 2 }
};
